@@ -3,7 +3,9 @@ from office365.communications.presences.presence import Presence
 from office365.delta_collection import DeltaCollection
 from office365.directory.authentication.authentication import Authentication
 from office365.directory.extensions.extension import Extension
+from office365.directory.insights.office_graph import OfficeGraphInsights
 from office365.directory.licenses.assigned_plan import AssignedPlan
+from office365.directory.permissions.grants.oauth2 import OAuth2PermissionGrant
 from office365.directory.users.settings import UserSettings
 from office365.onedrive.sites.site import Site
 from office365.onenote.onenote import Onenote
@@ -16,7 +18,7 @@ from office365.outlook.calendar.reminder import Reminder
 from office365.directory.licenses.assigned_license import AssignedLicense
 from office365.directory.object import DirectoryObject
 from office365.directory.object_collection import DirectoryObjectCollection
-from office365.directory.licenses.license_details import LicenseDetails
+from office365.directory.licenses.details import LicenseDetails
 from office365.directory.identities.object_identity import ObjectIdentity
 from office365.directory.profile_photo import ProfilePhoto
 from office365.entity_collection import EntityCollection
@@ -35,6 +37,7 @@ from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.paths.entity import EntityPath
+from office365.runtime.queries.function import FunctionQuery
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.types.collections import StringCollection
@@ -76,12 +79,14 @@ class User(DirectoryObject):
         self.context.add_query(qry)
         return self
 
-    def send_mail(self, subject, body, to_recipients, save_to_sent_items=False):
+    def send_mail(self, subject, body, to_recipients, cc_recipients=[], bcc_recipients=[], save_to_sent_items=False):
         """Send a new message on the fly
 
         :param str subject: The subject of the message.
         :param str body: The body of the message. It can be in HTML or text format
         :param list[str] to_recipients: The To: recipients for the message.
+        :param list[str] cc_recipients: The CC: recipients for the message.
+        :param list[str] bcc_recipients: The BCC: recipients for the message.
         :param bool save_to_sent_items: Indicates whether to save the message in Sent Items. Specify it only if
             the parameter is false; default is true
         """
@@ -89,6 +94,8 @@ class User(DirectoryObject):
         message.subject = subject
         message.body = body
         [message.to_recipients.add(Recipient.from_email(email)) for email in to_recipients]
+        [message.bcc_recipients.add(Recipient.from_email(email)) for email in bcc_recipients]
+        [message.cc_recipients.add(Recipient.from_email(email)) for email in cc_recipients]
 
         payload = {
             "message": message,
@@ -176,19 +183,14 @@ class User(DirectoryObject):
         :param datetime.datetime start_dt: The start date and time of the event for which the reminder is set up.
             The value is represented in ISO 8601 format, for example, "2015-11-08T19:00:00.0000000".
         """
-        result = ClientResult(self.context, ClientValueCollection(Reminder))
+        return_type = ClientResult(self.context, ClientValueCollection(Reminder))
         params = {
             "startDateTime": start_dt.isoformat(),
             "endDateTime": end_dt.isoformat(),
         }
-        qry = ServiceOperationQuery(self, "reminderView", params, None, None, result)
+        qry = FunctionQuery(self, "reminderView", params, return_type)
         self.context.add_query(qry)
-
-        def _construct_request(request):
-            request.method = HttpMethod.Get
-
-        self.context.before_execute(_construct_request)
-        return result
+        return return_type
 
     def delete_object(self, permanent_delete=False):
         """
@@ -357,6 +359,12 @@ class User(DirectoryObject):
                                    EntityCollection(self.context, Site,
                                                     ResourcePath("followedSites", self.resource_path)))
 
+    @property
+    def insights(self):
+        """"""
+        return self.properties.get('insights',
+                                   OfficeGraphInsights(self.context, ResourcePath("insights", self.resource_path)))
+
     @property
     def photo(self):
         """
@@ -368,7 +376,7 @@ class User(DirectoryObject):
     @property
     def manager(self):
         """
-        The user or contact that is this user's manager. Read-only. (HTTP Methods: GET, PUT, DELETE.)
+        The user or contact that is this user's manager
         """
         return self.properties.get('manager',
                                    DirectoryObject(self.context, ResourcePath("manager", self.resource_path)))
@@ -464,6 +472,13 @@ class User(DirectoryObject):
                                    DirectoryObjectCollection(self.context,
                                                              ResourcePath("memberOf", self.resource_path)))
 
+    @property
+    def oauth2_permission_grants(self):
+        """"""
+        return self.properties.get('oauth2PermissionGrants',
+                                   DeltaCollection(self.context, OAuth2PermissionGrant,
+                                                   ResourcePath("oauth2PermissionGrants", self.resource_path)))
+
     @property
     def transitive_member_of(self):
         """Get groups, directory roles that the user is a member of. This API request is transitive, and will also
@@ -506,8 +521,6 @@ class User(DirectoryObject):
     @property
     def extensions(self):
         """The collection of open extensions defined for the user. Nullable.
-
-        :rtype: EntityCollection
         """
         return self.properties.get('extensions',
                                    EntityCollection(self.context, Extension,
@@ -517,8 +530,6 @@ class User(DirectoryObject):
     def direct_reports(self):
         """
         Get a user's direct reports.
-
-        :rtype: EntityCollection
         """
         return self.properties.get('directReports',
                                    DirectoryObjectCollection(self.context,
@@ -528,8 +539,6 @@ class User(DirectoryObject):
     def online_meetings(self):
         """
         Get a user's online meetings.
-
-        :rtype: OnlineMeetingCollection
         """
         return self.properties.get('onlineMeetings',
                                    OnlineMeetingCollection(self.context,
@@ -567,7 +576,9 @@ class User(DirectoryObject):
                 "assignedLicenses": self.assigned_licenses,
                 "mailFolders": self.mail_folders,
                 "mailboxSettings": self.mailbox_settings,
-                "directReports": self.direct_reports
+                "directReports": self.direct_reports,
+                "onlineMeetings": self.online_meetings,
+                "oauth2PermissionGrants": self.oauth2_permission_grants
             }
             default_value = property_mapping.get(name, None)
         return super(User, self).get_property(name, default_value)
