@@ -1,7 +1,7 @@
 from office365.communications.cloud_communications import CloudCommunications
 from office365.delta_collection import DeltaCollection
 from office365.directory.applications.application import Application
-from office365.directory.applications.application_template import ApplicationTemplate
+from office365.directory.applications.template import ApplicationTemplate
 from office365.directory.applications.service_principal import ServicePrincipal
 from office365.directory.audit.log_root import AuditLogRoot
 from office365.directory.directory import Directory
@@ -13,11 +13,14 @@ from office365.directory.identities.container import IdentityContainer
 from office365.directory.identities.provider import IdentityProvider
 from office365.directory.internal.paths.me import MePath
 from office365.directory.licenses.subscribed_sku import SubscribedSku
-from office365.directory.resource_specific_permission_grant import ResourceSpecificPermissionGrant
-from office365.intune.organizations.org_contact import OrgContact
+from office365.directory.permissions.grants.resource_specific import ResourceSpecificPermissionGrant
+from office365.directory.roles.management import RoleManagement
+from office365.directory.roles.role import DirectoryRole
+from office365.intune.devices.app_management import DeviceAppManagement
+from office365.intune.devices.management import DeviceManagement
+from office365.intune.organizations.contact import OrgContact
 from office365.intune.organizations.organization import Organization
 from office365.directory.policies.root import PolicyRoot
-from office365.directory.subscriptions.subscription import Subscription
 from office365.directory.users.user import User
 from office365.directory.users.collection import UserCollection
 from office365.education.root import EducationRoot
@@ -39,7 +42,8 @@ from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.queries.delete_entity import DeleteEntityQuery
 from office365.runtime.queries.update_entity import UpdateEntityQuery
 from office365.search.entity import SearchEntity
-from office365.security.security import Security
+from office365.directory.security.security import Security
+from office365.subscriptions.subscription import Subscription
 from office365.teams.chats.collection import ChatCollection
 from office365.teams.collection import TeamCollection
 from office365.teams.template import TeamsTemplate
@@ -106,6 +110,16 @@ class GraphClient(ClientRuntimeContext):
         """The Me endpoint is provided as a shortcut for specifying the current user"""
         return User(self, MePath())
 
+    @property
+    def device_management(self):
+        """Singleton entity that acts as a container for all device management functionality."""
+        return DeviceManagement(self, ResourcePath("deviceManagement"))
+
+    @property
+    def device_app_management(self):
+        """Singleton entity that acts as a container for all device and app management functionality."""
+        return DeviceAppManagement(self, ResourcePath("deviceAppManagement"))
+
     @property
     def drives(self):
         """Get one drives"""
@@ -143,12 +157,12 @@ class GraphClient(ClientRuntimeContext):
 
     @property
     def chats(self):
-        """Get teams"""
+        """Get chats"""
         return ChatCollection(self, ResourcePath("chats"))
 
     @property
     def group_setting_templates(self):
-        """Get teams"""
+        """Group setting templates represent system-defined settings available to the tenant."""
         return EntityCollection(self, GroupSettingTemplate, ResourcePath("groupSettingTemplates"))
 
     @property
@@ -161,6 +175,11 @@ class GraphClient(ClientRuntimeContext):
         """Represents a deleted item in the directory"""
         return Directory(self, ResourcePath("directory"))
 
+    @property
+    def directory_roles(self):
+        """Represents a directory roles in the directory"""
+        return DeltaCollection(self, DirectoryRole, ResourcePath("directoryRoles"))
+
     @property
     def identity_providers(self):
         return EntityCollection(self, IdentityProvider, ResourcePath("identityProviders"))
@@ -235,6 +254,10 @@ class GraphClient(ClientRuntimeContext):
         """
         return ReportRoot(self, ResourcePath("reports"))
 
+    @property
+    def role_management(self):
+        return RoleManagement(self, ResourcePath("roleManagement"))
+
     @property
     def teams_templates(self):
         """
