@@ -1,6 +1,5 @@
 import os
 
-from office365.directory.subscriptions.subscription import Subscription
 from office365.onedrive.driveitems.audio import Audio
 from office365.onedrive.driveitems.geo_coordinates import GeoCoordinates
 from office365.onedrive.driveitems.image import Image
@@ -29,9 +28,11 @@ from office365.onedrive.internal.paths.url import UrlPath
 from office365.runtime.client_result import ClientResult
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.queries.create_entity import CreateEntityQuery
+from office365.runtime.queries.function import FunctionQuery
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.queries.upload_session import UploadSessionQuery
+from office365.subscriptions.subscription import Subscription
 
 
 class DriveItem(BaseItem):
@@ -46,6 +47,14 @@ class DriveItem(BaseItem):
         """
         return DriveItem(self.context, UrlPath(url_path, self.resource_path), self.children)
 
+    def create_powerpoint(self, name):
+        """
+        Creates a PowerPoint file
+
+        :param str name:
+        """
+        return self.upload(name, None)
+
     def create_link(self, link_type, scope="", expiration_datetime=None, password=None, message=None):
         """
         The createLink action will create a new sharing link if the specified link type doesn't already exist
@@ -67,11 +76,11 @@ class DriveItem(BaseItem):
             "expirationDateTime": expiration_datetime,
             "password": password
         }
-        permission = Permission(self.context)
-        self.permissions.add_child(permission)
-        qry = ServiceOperationQuery(self, "createLink", None, payload, None, permission)
+        return_type = Permission(self.context)
+        self.permissions.add_child(return_type)
+        qry = ServiceOperationQuery(self, "createLink", None, payload, None, return_type)
         self.context.add_query(qry)
-        return permission
+        return return_type
 
     def follow(self):
         """
@@ -154,7 +163,7 @@ class DriveItem(BaseItem):
         :param name: The contents of the request body should be the binary stream of the file to be uploaded.
         :type name: str
         :param content: The contents of the request body should be the binary stream of the file to be uploaded.
-        :type content: str or bytes
+        :type content: str or bytes or None
         :rtype: DriveItem
         """
         qry = create_upload_content_query(self, name, content)
@@ -298,15 +307,7 @@ class DriveItem(BaseItem):
         :type query_text: str
         """
         return_type = EntityCollection(self.context, DriveItem, ResourcePath("items", self.resource_path))
-        qry = ServiceOperationQuery(self, "search", {"q": query_text}, None, None, return_type)
-
-        def _construct_query(request):
-            """
-            :type request: office365.runtime.http.request_options.RequestOptions
-            """
-            request.method = HttpMethod.Get
-
-        self.context.before_execute(_construct_query)
+        qry = FunctionQuery(self, "search", {"q": query_text}, return_type)
         self.context.add_query(qry)
         return return_type
 
@@ -353,13 +354,8 @@ class DriveItem(BaseItem):
             "interval": interval
         }
         return_type = EntityCollection(self.context, ItemActivityStat, self.resource_path)
-        qry = ServiceOperationQuery(self, "getActivitiesByInterval", params, None, None, return_type)
+        qry = FunctionQuery(self, "getActivitiesByInterval", params, return_type)
         self.context.add_query(qry)
-
-        def _construct_request(request):
-            request.method = HttpMethod.Get
-
-        self.context.before_execute(_construct_request)
         return return_type
 
     def restore(self, parent_reference, name):
@@ -399,7 +395,7 @@ class DriveItem(BaseItem):
         self.context.add_query(qry)
         return result
 
-    def validate_permission(self, challenge_token, password):
+    def validate_permission(self, challenge_token=None, password=None):
         """
         :type challenge_token: str
         :type password: str
@@ -408,8 +404,7 @@ class DriveItem(BaseItem):
             "challengeToken": challenge_token,
             "password": password
         }
-        result = ClientResult(self.context, ItemPreviewInfo())
-        qry = ServiceOperationQuery(self, "validatePermission", None, payload, None, result)
+        qry = ServiceOperationQuery(self, "validatePermission", None, payload)
         self.context.add_query(qry)
         return self
 
@@ -550,12 +545,10 @@ class DriveItem(BaseItem):
     @property
     def subscriptions(self):
         """The set of subscriptions on the driveItem.
-
-        :rtype: EntityCollection
         """
-        return self.get_property('subscriptions',
-                                 EntityCollection(self.context, Subscription,
-                                                  ResourcePath("subscriptions", self.resource_path)))
+        return self.properties.get('subscriptions',
+                                   EntityCollection(self.context, Subscription,
+                                                    ResourcePath("subscriptions", self.resource_path)))
 
     def get_property(self, name, default_value=None):
         if default_value is None:
