@@ -1,3 +1,4 @@
+from office365.directory.identities.identity_set import IdentitySet
 from office365.runtime.client_value import ClientValue
 
 
@@ -9,3 +10,6 @@ class RemoteItem(ClientValue):
     DriveItems with a non-null remoteItem facet are resources that are shared, added to the user's OneDrive,
     or on items returned from hetrogenous collections of items (like search results).
     """
+
+    def __init__(self, created_by=IdentitySet()):
+        self.createdBy = created_by
