@@ -1,5 +1,5 @@
 from office365.runtime.client_result import ClientResult
-from office365.runtime.http.http_method import HttpMethod
+from office365.runtime.queries.function import FunctionQuery
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 
 
@@ -12,15 +12,7 @@ def create_download_content_query(file_item, format_name=None):
     action_name = "content"
     if format_name is not None:
         action_name = action_name + r"?format={0}".format(format_name)
-    qry = ServiceOperationQuery(file_item, action_name, None, None, None, return_type)
-
-    def _construct_query(request):
-        """
-        :type request: office365.runtime.http.request_options.RequestOptions
-        """
-        request.method = HttpMethod.Get
-    file_item.context.before_execute(_construct_query)
-    return qry
+    return FunctionQuery(file_item, action_name, None, return_type)
 
 
 def create_download_session_content_query(file_item, format_name=None):
@@ -31,5 +23,4 @@ def create_download_session_content_query(file_item, format_name=None):
     action_name = "content"
     if format_name is not None:
         action_name = action_name + r"?format={0}".format(format_name)
-    qry = ServiceOperationQuery(file_item, action_name)
-    return qry
+    return ServiceOperationQuery(file_item, action_name)
