@@ -2,7 +2,7 @@ from office365.outlook.calendar.permission import CalendarPermission
 from office365.outlook.calendar.dateTimeTimeZone import DateTimeTimeZone
 from office365.outlook.calendar.email_address import EmailAddress
 from office365.outlook.calendar.event import Event
-from office365.outlook.calendar.schedule_information import ScheduleInformation
+from office365.outlook.calendar.schedule.information import ScheduleInformation
 from office365.entity import Entity
 from office365.entity_collection import EntityCollection
 from office365.runtime.client_result import ClientResult
@@ -35,10 +35,10 @@ class Calendar(Entity):
             "endTime": DateTimeTimeZone.parse(end_time),
             "availabilityViewInterval": availability_view_interval
         }
-        result = ClientResult(self.context, ClientValueCollection(ScheduleInformation))
-        qry = ServiceOperationQuery(self, "getSchedule", None, payload, None, result)
+        return_type = ClientResult(self.context, ClientValueCollection(ScheduleInformation))
+        qry = ServiceOperationQuery(self, "getSchedule", None, payload, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     @property
     def can_edit(self):
