@@ -3,14 +3,15 @@ import copy
 from office365.runtime.auth.authentication_context import AuthenticationContext
 from office365.runtime.auth.user_credential import UserCredential
 from office365.runtime.client_runtime_context import ClientRuntimeContext
+from office365.runtime.compat import urlparse, is_absolute_url, get_absolute_url
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
-from office365.runtime.odata.v3.json_light_format import JsonLightFormat
-from office365.runtime.odata.v3.batch_request import ODataBatchV3Request
 from office365.runtime.odata.request import ODataRequest
+from office365.runtime.odata.v3.batch_request import ODataBatchV3Request
+from office365.runtime.odata.v3.json_light_format import JsonLightFormat
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.queries.delete_entity import DeleteEntityQuery
 from office365.runtime.queries.update_entity import UpdateEntityQuery
-from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.portal.sites.status import SiteStatus
 from office365.sharepoint.publishing.pages.service import SitePageService
 from office365.sharepoint.request_user_context import RequestUserContext
@@ -18,7 +19,6 @@ from office365.sharepoint.sites.site import Site
 from office365.sharepoint.tenant.administration.hubsites.collection import HubSiteCollection
 from office365.sharepoint.webs.context_web_information import ContextWebInformation
 from office365.sharepoint.webs.web import Web
-from office365.runtime.compat import urlparse, is_absolute_url, get_absolute_url
 
 
 class ClientContext(ClientRuntimeContext):
@@ -228,15 +228,17 @@ class ClientContext(ClientRuntimeContext):
                 request.ensure_header("X-HTTP-Method", "MERGE")
                 request.ensure_header("IF-MATCH", '*')
 
-    def create_team_site(self, alias, title, is_public=True):
-        """Creates a modern SharePoint Team site
+    def create_modern_site(self, title, alias, owner=None):
+        """
+        Creates a modern site
 
-        :param str alias: Site alias which defines site url, e.g. https://contoso.sharepoint.com/teams/{alias}
+        :param str alias: Site alias which defines site url, e.g. https://contoso.sharepoint.com/sites/{alias}
         :param str title: Site title
-        :param bool is_public:
+        :param str or office365.sharepoint.principal.user.User owner: Site owner
         """
-        result = self.group_site_manager.create_group_ex(title, alias, is_public)
         return_type = Site(self)
+        site_url = "{base_url}/sites/{alias}".format(base_url=get_absolute_url(self.base_url), alias=alias)
+        result = self.site_manager.create(title, site_url, owner)
 
         def _after_site_create(resp):
             """
@@ -247,10 +249,32 @@ class ClientContext(ClientRuntimeContext):
                 raise ValueError(result.value.ErrorMessage)
             elif result.value.SiteStatus == SiteStatus.Ready:
                 return_type.set_property("__siteUrl", result.value.SiteUrl)
-
         self.after_execute(_after_site_create)
         return return_type
 
+    def create_team_site(self, alias, title, is_public=True):
+        """Creates a modern SharePoint Team site
+
+        :param str alias: Site alias which defines site url, e.g. https://contoso.sharepoint.com/teams/{alias}
+        :param str title: Site title
+        :param bool is_public:
+        """
+        result = self.group_site_manager.create_group_ex(title, alias, is_public)
+        return_type = Site(self)
+
+        def _after_site_created(resp):
+            """
+            :type resp: requests.Response
+            """
+            resp.raise_for_status()
+            if result.value.SiteStatus == SiteStatus.Error:
+                raise ValueError(result.value.ErrorMessage)
+            elif result.value.SiteStatus == SiteStatus.Ready:
+                return_type.set_property("__siteUrl", result.value.SiteUrl)
+
+        self.after_execute(_after_site_created)
+        return return_type
+
     def create_communication_site(self, alias, title):
         """
         Creates a modern SharePoint Communication site
@@ -259,17 +283,18 @@ class ClientContext(ClientRuntimeContext):
         :param str title: Site title
         """
         return_type = Site(self)
-        result = self.site_pages.communication_site.create(alias, title)
+        site_url = "{base_url}/sites/{alias}".format(base_url=get_absolute_url(self.base_url), alias=alias)
+        site_result = self.site_pages.communication_site.create(title, site_url)
 
         def _after_site_create(resp):
             """
             :type resp: requests.Response
             """
             resp.raise_for_status()
-            if result.value.SiteStatus == SiteStatus.Error:
+            if site_result.value.SiteStatus == SiteStatus.Error:
                 raise ValueError("Site creation error")
-            elif result.value.SiteStatus == SiteStatus.Ready:
-                return_type.set_property("__siteUrl", result.value.SiteUrl)
+            elif site_result.value.SiteStatus == SiteStatus.Ready:
+                return_type.set_property("__siteUrl", site_result.value.SiteUrl)
         self.after_execute(_after_site_create)
         return return_type
 
@@ -297,6 +322,11 @@ class ClientContext(ClientRuntimeContext):
             self._site = Site(self)
         return self._site
 
+    @property
+    def apps(self):
+        from office365.sharepoint.apps.app_collection import AppCollection
+        return AppCollection(self, ResourcePath("Apps"))
+
     @property
     def me(self):
         """Gets the user context for the present request"""
@@ -314,10 +344,16 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.microservice.manager import MicroServiceManager
         return MicroServiceManager(self, ResourcePath("microServiceManager"))
 
+    @property
+    def directory_session(self):
+        """Alias to DirectorySession"""
+        from office365.sharepoint.directory.session import DirectorySession
+        return DirectorySession(self)
+
     @property
     def models(self):
         """Alias to collection of SPMachineLearningModel"""
-        from office365.sharepoint.contentcenter.machinelearning.model_collection import SPMachineLearningModelCollection
+        from office365.sharepoint.contentcenter.machinelearning.models.collection import SPMachineLearningModelCollection
         return SPMachineLearningModelCollection(self, ResourcePath("models"))
 
     @property
@@ -332,6 +368,12 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.portal.groups.service import GroupService
         return GroupService(self, ResourcePath("GroupService"))
 
+    @property
+    def navigation_service(self):
+        """Alias to NavigationService"""
+        from office365.sharepoint.navigation.navigation_service import NavigationService
+        return NavigationService(self)
+
     @property
     def page_diagnostics(self):
         """Alias to PageDiagnosticsController"""
@@ -373,6 +415,24 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.contentcenter.machinelearning.hub import SPMachineLearningHub
         return SPMachineLearningHub(self, ResourcePath("machinelearning"))
 
+    @property
+    def org_news(self):
+        """Alias to OrgNewsSite"""
+        from office365.sharepoint.portal.organization_news import OrganizationNews
+        return OrganizationNews(self, ResourcePath("OrgNews"))
+
+    @property
+    def org_news_site(self):
+        """Alias to OrgNewsSite"""
+        from office365.sharepoint.orgnewssite.api import OrgNewsSiteApi
+        return OrgNewsSiteApi(self, ResourcePath("OrgNewsSite"))
+
+    @property
+    def search_setting(self):
+        """Alias to SearchSetting"""
+        from office365.sharepoint.search.setting import SearchSetting
+        return SearchSetting(self)
+
     @property
     def site_pages(self):
         """Alias to SitePageService. Represents a set of APIs to use for managing site pages."""
@@ -396,6 +456,29 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.portal.sites.manager import SPSiteManager
         return SPSiteManager(self, ResourcePath("spSiteManager"))
 
+    @property
+    def home_service(self):
+        """Alias to SharePointHomeServiceContextBuilder."""
+        from office365.sharepoint.portal.home.service_context_builder import SharePointHomeServiceContextBuilder
+        return SharePointHomeServiceContextBuilder(self, ResourcePath("sphomeservice"))
+
+    @property
+    def home_site(self):
+        """Alias to SPHSite."""
+        from office365.sharepoint.sites.sph_site import SPHSite
+        return SPHSite(self, ResourcePath("SPHSite"))
+
+    @property
+    def publications(self):
+        from office365.sharepoint.base_entity_collection import BaseEntityCollection
+        from office365.sharepoint.contentcenter.machinelearning.publications.publication import SPMachineLearningPublication
+        return BaseEntityCollection(self, SPMachineLearningPublication, ResourcePath("publications"))
+
+    @property
+    def social_following_manager(self):
+        from office365.sharepoint.social.following.manager import SocialFollowingManager
+        return SocialFollowingManager(self)
+
     @property
     def theme_manager(self):
         """Alias to SP.Utilities.ThemeManager. Represents methods for creating and managing site theming"""
@@ -420,6 +503,12 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.tenant.settings import TenantSettings
         return TenantSettings.current(self)
 
+    @property
+    def work_items(self):
+        from office365.sharepoint.contentcenter.machinelearning.workitems.collection import \
+            SPMachineLearningWorkItemCollection
+        return SPMachineLearningWorkItemCollection(self, ResourcePath("workitems"))
+
     @property
     def tenant(self):
         from office365.sharepoint.tenant.administration.tenant import Tenant
