@@ -1,5 +1,6 @@
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
+from office365.runtime.types.collections import StringCollection
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.contenttypes.content_type_id import ContentTypeId
 from office365.sharepoint.contenttypes.fieldlinks.collection import FieldLinkCollection
@@ -14,9 +15,13 @@ class ContentType(BaseEntity):
         """
         The ReorderFields method is called to change the order in which fields appear in a content type.
 
-        :param list[str] field_names:
+        :param list[str] field_names: Rearranges the collection of fields in the order in which field internal
+             names are specified.
         """
-        qry = ServiceOperationQuery(self, "ReorderFields", field_names)
+        payload = {
+            "fieldNames": StringCollection(field_names)
+        }
+        qry = ServiceOperationQuery(self, "ReorderFields", None, payload)
         self.context.add_query(qry)
         return self
 
@@ -29,10 +34,26 @@ class ContentType(BaseEntity):
         """
         super(ContentType, self).update()
         if update_children:
-            qry = ServiceOperationQuery(self, "Update", [update_children])
+            payload = {"updateChildren": update_children}
+            qry = ServiceOperationQuery(self, "Update", None, payload)
             self.context.add_query(qry)
         return self
 
+    @property
+    def display_form_template_name(self):
+        """
+        Specifies the name of a custom display form template to use for list items that have been assigned
+        the content type.
+        """
+        return self.properties.get("DisplayFormTemplateName", None)
+
+    @property
+    def display_form_url(self):
+        """
+        Specifies the URL of a custom display form to use for list items that have been assigned the content type.
+        """
+        return self.properties.get("DisplayFormUrl", None)
+
     @property
     def id(self):
         """Specifies an identifier for the content type as specified in [MS-WSSTS] section 2.1.2.8.1.
@@ -105,6 +126,21 @@ class ContentType(BaseEntity):
         """
         self.set_property("Group", value)
 
+    @property
+    def hidden(self):
+        """Specifies whether the content type is unavailable for creation or usage directly from a user interface."""
+        return self.properties.get("Hidden", None)
+
+    @property
+    def js_link(self):
+        """Gets or sets the JSLink for the content type custom form template"""
+        return self.properties.get("JSLink", None)
+
+    @property
+    def read_only(self):
+        """Specifies whether changes to the content type properties are denied."""
+        return self.properties.get("ReadOnly", None)
+
     @property
     def name_resource(self):
         """Specifies the SP.UserResource object for the name of this content type"""
