@@ -1,7 +1,7 @@
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.permissions.base_permissions import BasePermissions
-from office365.sharepoint.types.user_resource import UserResource
+from office365.sharepoint.translation.user_resource import UserResource
 
 
 class UserCustomAction(BaseEntity):
