@@ -16,6 +16,12 @@ class GroupSiteManager(ClientObject):
             resource_path = ResourcePath("GroupSiteManager")
         super(GroupSiteManager, self).__init__(context, resource_path)
 
+    def can_user_create_group(self):
+        return_type = ClientResult(self.context, bool())
+        qry = ServiceOperationQuery(self, "CanUserCreateGroup", None, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def create_group_for_site(self, display_name, alias, is_public=None, optional_params=None):
         """
         Create a modern site
@@ -38,7 +44,7 @@ class GroupSiteManager(ClientObject):
 
     def create_group_ex(self, display_name, alias, is_public, optional_params=None):
         """
-        Create a modern site
+        Creates a modern site
 
         :param str display_name:
         :param str alias:
@@ -99,7 +105,7 @@ class GroupSiteManager(ClientObject):
         :type get_logo_data: bool
         :type force_cache_update: bool
         """
-        result = ClientResult(self.context)
+        result = ClientResult(self.context, str())
         payload = {
             "getLogoData": get_logo_data,
             "forceCacheUpdate": force_cache_update
@@ -128,6 +134,18 @@ class GroupSiteManager(ClientObject):
         self.context.add_query(qry)
         return return_type
 
+    def get_team_channels_direct(self, team_id):
+        """
+        :param str team_id:
+        """
+        return_type = ClientResult(self.context, str())
+        payload = {
+            "teamId": team_id,
+        }
+        qry = ServiceOperationQuery(self, "GetTeamChannelsDirect", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def notebook(self, group_id):
         """
         :param str group_id:
