@@ -12,3 +12,11 @@ class SharePointSharingSettings(BaseEntity):
         to search for and resolve desired users and groups."""
         return self.properties.get('PickerProperties',
                                    PickerSettings(self.context, ResourcePath("PickerProperties", self.resource_path)))
+
+    def get_property(self, name, default_value=None):
+        if default_value is None:
+            property_mapping = {
+                "PickerProperties": self.picker_properties,
+            }
+            default_value = property_mapping.get(name, None)
+        return super(SharePointSharingSettings, self).get_property(name, default_value)
