@@ -7,14 +7,17 @@ from office365.sharepoint.audit.audit import Audit
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.changes.collection import ChangeCollection
 from office365.sharepoint.changes.token import ChangeToken
+from office365.sharepoint.compliance.store_proxy import SPPolicyStoreProxy
+from office365.sharepoint.compliance.tag import ComplianceTag
 from office365.sharepoint.eventreceivers.definition_collection import EventReceiverDefinitionCollection
 from office365.sharepoint.features.collection import FeatureCollection
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.portal.sites.icon_manager import SiteIconManager
-from office365.sharepoint.principal.user import User
+from office365.sharepoint.principal.users.user import User
 from office365.sharepoint.recyclebin.item_collection import RecycleBinItemCollection
 from office365.sharepoint.sitehealth.summary import SiteHealthSummary
 from office365.sharepoint.sites.sph_site import SPHSite
+from office365.sharepoint.sites.azure_container_Info import ProvisionedTemporaryAzureContainerInfo
 from office365.sharepoint.sites.upgrade_info import UpgradeInfo
 from office365.sharepoint.sites.usage_info import UsageInfo
 from office365.sharepoint.tenant.administration.site_administrators_info import SiteAdministratorsInfo
@@ -60,9 +63,21 @@ class Site(BaseEntity):
         """Deletes a site"""
 
         def _site_resolved():
-            self.context.group_site_manager.delete(self.url)
+            if self.group_id == "00000000-0000-0000-0000-000000000000":
+                self.context.site_manager.delete(self.id)
+            else:
+                self.context.group_site_manager.delete(self.url)
 
-        self.ensure_property("Url", _site_resolved)
+        self.ensure_properties(["Url", "GroupId", "Id"], _site_resolved)
+        return self
+
+    def extend_upgrade_reminder_date(self):
+        """
+        Extend the upgrade reminder date for this site collection, so that site collection administrators will
+        not be reminded to run a site collection upgrade before the new date
+        """
+        qry = ServiceOperationQuery(self, "ExtendUpgradeReminderDate")
+        self.context.add_query(qry)
         return self
 
     @staticmethod
@@ -75,6 +90,15 @@ class Site(BaseEntity):
         from office365.sharepoint.client_context import ClientContext
         return ClientContext(url).site
 
+    def get_available_tags(self):
+        return_type = ClientResult(self.context, ClientValueCollection(ComplianceTag))
+
+        def _site_loaded():
+            SPPolicyStoreProxy.get_available_tags_for_site(self.context, self.url, return_type)
+
+        self.ensure_property("Url", _site_loaded)
+        return return_type
+
     def get_site_logo(self):
         """
         Downloads a site logo
@@ -82,9 +106,7 @@ class Site(BaseEntity):
         return_type = ClientResult(self.context)
 
         def _site_loaded():
-            site_manager = SiteIconManager(self.context)
-            site_manager.get_site_logo(self.url, return_type=return_type)
-
+            self.context.site_icon_manager.get_site_logo(self.url, return_type=return_type)
         self.ensure_property("Url", _site_loaded)
         return return_type
 
@@ -128,7 +150,7 @@ class Site(BaseEntity):
         return_type = ClientResult(self.context)
 
         def _site_loaded():
-            self.result = SPHSite.set_as_home_site(self.context, self.url, return_type)
+            self.result = SPHSite.set_as_home_site(self.context, self.url, False, return_type)
 
         self.ensure_property("Url", _site_loaded)
         return return_type
@@ -165,6 +187,7 @@ class Site(BaseEntity):
 
         def _site_loaded():
             self.context.tenant.get_site_administrators(self.id, return_type)
+
         self.ensure_property("Id", _site_loaded)
         return return_type
 
@@ -242,15 +265,15 @@ class Site(BaseEntity):
         :type site_id: str
         :type stop_redirect: bool
         """
-        result = ClientResult(context)
+        return_type = ClientResult(context, str())
         payload = {
             "id": site_id,
             "stopRedirect": stop_redirect
         }
-        qry = ServiceOperationQuery(context.site, "GetUrlById", None, payload, None, result)
+        qry = ServiceOperationQuery(context.site, "GetUrlById", None, payload, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def get_url_by_id_for_web(context, site_id, stop_redirect, web_id):
@@ -277,16 +300,15 @@ class Site(BaseEntity):
         """Determine whether site exists
 
         :type context: office365.sharepoint.client_context.ClientContext
-        :type url: str
+        :param str url: The absolute url of a site.
         """
-        result = ClientResult(context)
+        return_type = ClientResult(context, bool())
         payload = {
             "url": url
         }
-        qry = ServiceOperationQuery(context.site, "Exists", None, payload, None, result)
-        qry.static = True
+        qry = ServiceOperationQuery(context.site, "Exists", None, payload, None, return_type, True)
         context.add_query(qry)
-        return result
+        return return_type
 
     def get_catalog(self, type_catalog):
         """
@@ -319,6 +341,13 @@ class Site(BaseEntity):
         self.context.add_query(qry)
         return return_type
 
+    def provision_temporary_azure_container(self):
+        """"""
+        return_type = ClientResult(self.context, ProvisionedTemporaryAzureContainerInfo())
+        qry = ServiceOperationQuery(self, "ProvisionTemporaryAzureContainer", None, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def register_hub_site(self, create_info=None):
         """Registers an existing site as a hub site.
 
@@ -407,6 +436,25 @@ class Site(BaseEntity):
         """
         return self.properties.get("Classification", None)
 
+    @property
+    def compatibility_level(self):
+        """
+        Specifies the compatibility level of the site collection for the purpose of major version level compatibility
+        checks
+
+        :rtype: str
+        """
+        return self.properties.get('CompatibilityLevel', None)
+
+    @property
+    def comments_on_site_pages_disabled(self):
+        """
+        Indicates whether comments on site pages are disabled or not.
+
+        :rtype: bool
+        """
+        return self.properties.get('CommentsOnSitePagesDisabled', None)
+
     @property
     def current_change_token(self):
         """Gets the current change token that is used in the change log for the site collection."""
@@ -419,6 +467,15 @@ class Site(BaseEntity):
         """
         return self.properties.get("GroupId", None)
 
+    @property
+    def lock_issue(self):
+        """
+        Specifies the comment that is used when a site collection is locked
+
+        :rtype: str or None
+        """
+        return self.properties.get("LockIssue", None)
+
     @property
     def root_web(self):
         """Get root web"""
