@@ -14,6 +14,7 @@ from office365.sharepoint.sites.home_sites_details import HomeSitesDetails
 from office365.sharepoint.sites.site import Site
 from office365.sharepoint.tenant.administration.collaboration.insights_data import CollaborationInsightsData
 from office365.sharepoint.tenant.administration.hubsites.properties import HubSiteProperties
+from office365.sharepoint.tenant.administration.insights.onedrive_site_sharing import OneDriveSiteSharingInsights
 from office365.sharepoint.tenant.administration.secondary_administrators_fields_data import \
     SecondaryAdministratorsFieldsData
 from office365.sharepoint.tenant.administration.secondary_administrators_info import SecondaryAdministratorsInfo
@@ -22,8 +23,9 @@ from office365.sharepoint.tenant.administration.site_creation_properties import
 from office365.sharepoint.tenant.administration.site_properties import SiteProperties
 from office365.sharepoint.tenant.administration.site_properties_collection import SitePropertiesCollection
 from office365.sharepoint.tenant.administration.site_properties_enumerable_filter import SitePropertiesEnumerableFilter
+from office365.sharepoint.tenant.administration.siteinfo_for_site_picker import SiteInfoForSitePicker
 from office365.sharepoint.tenant.administration.spo_operation import SpoOperation
-from office365.sharepoint.tenant.administration.top_files_sharing_insights import TopFilesSharingInsights
+from office365.sharepoint.tenant.administration.insights.top_files_sharing import TopFilesSharingInsights
 
 
 class Tenant(BaseEntity):
@@ -33,6 +35,29 @@ class Tenant(BaseEntity):
         static_path = ResourcePath("Microsoft.Online.SharePoint.TenantAdministration.Tenant")
         super(Tenant, self).__init__(context, static_path)
 
+    def delete_policy_definition(self, item_id):
+        """
+        :param int item_id:
+        """
+        qry = ServiceOperationQuery(self, "DeletePolicyDefinition", None, {"itemId": item_id})
+        self.context.add_query(qry)
+        return self
+
+    def delete_recent_admin_action_report(self, report_id):
+        """
+        :param int report_id:
+        """
+        qry = ServiceOperationQuery(self, "DeleteRecentAdminActionReport", None, {"reportId": report_id})
+        self.context.add_query(qry)
+        return self
+
+    def get_onedrive_site_sharing_insights(self, query_mode):
+        return_type = ClientResult(self.context, OneDriveSiteSharingInsights())
+        payload = {"queryMode": query_mode}
+        qry = ServiceOperationQuery(self, "GetOneDriveSiteSharingInsights", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_collaboration_insights_data(self):
         return_type = ClientResult(self.context, CollaborationInsightsData())
         qry = ServiceOperationQuery(self, "GetCollaborationInsightsData", None, None, None, return_type)
@@ -49,7 +74,7 @@ class Tenant(BaseEntity):
         self.context.add_query(qry)
         return return_type
 
-    def get_top_files_sharing_insights(self, query_mode=None):
+    def get_top_files_sharing_insights(self, query_mode):
         """
         :param int query_mode:
         """
@@ -64,7 +89,7 @@ class Tenant(BaseEntity):
         :param str site_url:
         """
         payload = {"siteUrl": site_url}
-        return_type = ClientResult(self.context)
+        return_type = ClientResult(self.context, bytes())
         qry = ServiceOperationQuery(self, "GetSiteThumbnailLogo", None, payload, None, return_type)
         self.context.add_query(qry)
         return return_type
@@ -98,7 +123,8 @@ class Tenant(BaseEntity):
         return return_type
 
     def has_valid_education_license(self):
-        return_type = ClientResult(self.context)
+        """"""
+        return_type = ClientResult(self.context, bool())
         qry = ServiceOperationQuery(self, "HasValidEducationLicense", None, None, None, return_type)
         self.context.add_query(qry)
         return return_type
@@ -107,16 +133,17 @@ class Tenant(BaseEntity):
         """
         :param str view_xml:
         """
-        result = ClientResult(self.context)
+        return_type = ClientResult(self.context)
         payload = {
             "viewXml": view_xml
         }
-        qry = ServiceOperationQuery(self, "ExportToCSV", None, payload, None, result)
+        qry = ServiceOperationQuery(self, "ExportToCSV", None, payload, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def render_policy_report(self):
-        return_type = ClientResult(self.context)
+        """"""
+        return_type = ClientResult(self.context, bytes())
         payload = {
             "parameters": RenderListDataParameters(),
             "overrideParameters": RenderListDataOverrideParameters()
@@ -294,11 +321,11 @@ class Tenant(BaseEntity):
 
         :param str site_url: A string representing the URL of the site.
         """
-        result = SpoOperation(self.context)
+        return_type = SpoOperation(self.context)
         params = {"siteUrl": site_url}
-        qry = ServiceOperationQuery(self, "removeSite", None, params, None, result)
+        qry = ServiceOperationQuery(self, "removeSite", None, params, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def remove_deleted_site(self, site_url):
         """Permanently removes the specified deleted site from the recycle bin.
@@ -310,15 +337,27 @@ class Tenant(BaseEntity):
         self.context.add_query(qry)
         return result
 
+    def reorder_home_sites(self, home_sites_site_ids):
+        """
+        :param list[str] home_sites_site_ids:
+        """
+        payload = {
+            "homeSitesSiteIds": home_sites_site_ids
+        }
+        return_type = ClientResult(self.context, ClientValueCollection(HomeSitesDetails))
+        qry = ServiceOperationQuery(self, "ReorderHomeSites", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def restore_deleted_site(self, site_url):
         """Restores deleted site with the specified URL
 
         :param str site_url: A string representing the URL of the site.
         """
-        result = SpoOperation(self.context)
-        qry = ServiceOperationQuery(self, "RestoreDeletedSite", [site_url], None, None, result)
+        return_type = SpoOperation(self.context)
+        qry = ServiceOperationQuery(self, "RestoreDeletedSite", [site_url], None, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def get_site_properties_by_url(self, url, include_detail=False):
         """
@@ -336,11 +375,11 @@ class Tenant(BaseEntity):
         self.context.add_query(qry)
         return return_type
 
-    def get_site_properties_from_sharepoint_by_filters(self, _filter, start_index=0, include_detail=False):
+    def get_site_properties_from_sharepoint_by_filters(self, _filter=None, start_index=None, include_detail=False):
         """
 
         :param bool include_detail:
-        :param int start_index:
+        :param str start_index:
         :param str _filter:
         """
         return_type = SitePropertiesCollection(self.context)
@@ -371,12 +410,16 @@ class Tenant(BaseEntity):
         """
         :type site_url: str
         """
-        return_type = ClientResult(self.context)
+        return_type = ClientResult(self.context, bool())
         payload = {"siteUrl": site_url}
         qry = ServiceOperationQuery(self, "SendEmail", None, payload, None, return_type)
         self.context.add_query(qry)
         return return_type
 
+    @property
+    def ai_builder_site_info_list(self):
+        return self.properties.get("AIBuilderSiteInfoList", ClientValueCollection(SiteInfoForSitePicker))
+
     @property
     def aggregated_site_collections_list(self):
         return self.context.web.lists.get_by_title("DO_NOT_DELETE_SPLIST_TENANTADMIN_AGGREGATED_SITECOLLECTIONS")
@@ -408,6 +451,10 @@ class Tenant(BaseEntity):
         """
         return self.properties.get('AllowEditing', None)
 
+    @property
+    def default_content_center_site(self):
+        return self.properties.get("DefaultContentCenterSite", SiteInfoForSitePicker())
+
     @property
     def root_site_url(self):
         """
