@@ -1,9 +1,11 @@
 # coding=utf-8
+
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.paths.service_operation import ServiceOperationPath
+from office365.runtime.types.collections import StringCollection
 from office365.sharepoint.activities.entity import SPActivityEntity
 from office365.sharepoint.activities.logger import ActivityLogger
 from office365.sharepoint.alerts.collection import AlertCollection
@@ -24,6 +26,7 @@ from office365.sharepoint.folders.folder import Folder
 from office365.sharepoint.folders.collection import FolderCollection
 from office365.sharepoint.listitems.listitem import ListItem
 from office365.sharepoint.lists.document_library_information import DocumentLibraryInformation
+from office365.sharepoint.lists.get_parameters import GetListsParameters
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.lists.collection import ListCollection
 from office365.sharepoint.lists.template_collection import ListTemplateCollection
@@ -31,10 +34,11 @@ from office365.sharepoint.navigation.navigation import Navigation
 from office365.sharepoint.permissions.base_permissions import BasePermissions
 from office365.sharepoint.permissions.roles.definitions.collection import RoleDefinitionCollection
 from office365.sharepoint.permissions.securable_object import SecurableObject
-from office365.sharepoint.principal.group import Group
-from office365.sharepoint.principal.group_collection import GroupCollection
-from office365.sharepoint.principal.user import User
-from office365.sharepoint.principal.user_collection import UserCollection
+from office365.sharepoint.principal.groups.group import Group
+from office365.sharepoint.principal.groups.collection import GroupCollection
+from office365.sharepoint.principal.users.user import User
+from office365.sharepoint.principal.users.collection import UserCollection
+from office365.sharepoint.pushnotifications.collection import PushNotificationSubscriberCollection
 from office365.sharepoint.pushnotifications.subscriber import PushNotificationSubscriber
 from office365.sharepoint.recyclebin.item_collection import RecycleBinItemCollection
 from office365.sharepoint.sharing.external_site_option import ExternalSharingSiteOption
@@ -57,7 +61,8 @@ from office365.sharepoint.webs.context_web_information import ContextWebInformat
 from office365.sharepoint.fields.datetime_field_format_type import DateTimeFieldFormatType
 from office365.sharepoint.webs.multilingual_settings import MultilingualSettings
 from office365.sharepoint.webs.regional_settings import RegionalSettings
-from office365.sharepoint.sitescripts.types import SiteScriptSerializationResult, SiteScriptSerializationInfo
+from office365.sharepoint.sitescripts.serialization_info import SiteScriptSerializationInfo
+from office365.sharepoint.sitescripts.serialization_result import SiteScriptSerializationResult
 from office365.sharepoint.webs.information_collection import WebInformationCollection
 from office365.sharepoint.webs.template_collection import WebTemplateCollection
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
@@ -145,24 +150,39 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
-    def get_push_notification_subscribers_by_user(self, user_or_username):
+    def get_client_side_components_by_component_type(self, component_types):
+        """
+        :param str component_types:
+        """
+        return_type = ClientResult(self.context, ClientValueCollection(SPClientSideComponentIdentifier))
+        payload = {
+            "componentTypesString": component_types
+        }
+        qry = ServiceOperationQuery(self, "GetClientSideComponentsByComponentType", None, payload,
+                                    None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
+    def get_push_notification_subscribers_by_user(self, user):
         """
         Queries for the push notification subscribers for the site  for the specified user.
 
-        :param str or User user_or_username:
+        :param str or User user: User object or login name
         """
-        return_type = BaseEntityCollection(self.context, PushNotificationSubscriber)
+        return_type = PushNotificationSubscriberCollection(self.context)
 
-        if isinstance(user_or_username, User):
+        def _create_query(login_name):
+            return ServiceOperationQuery(self, "GetPushNotificationSubscribersByUser",
+                                         [login_name], None, None, return_type)
+
+        if isinstance(user, User):
             def _user_loaded():
-                next_qry = ServiceOperationQuery(self, "GetPushNotificationSubscribersByUser",
-                                                 [user_or_username.login_name], None, None, return_type)
+                next_qry = _create_query(user.login_name)
                 self.context.add_query(next_qry)
 
-            user_or_username.ensure_property("LoginName", _user_loaded)
+            user.ensure_property("LoginName", _user_loaded)
         else:
-            qry = ServiceOperationQuery(self, "GetPushNotificationSubscribersByUser", [user_or_username], None,
-                                        None, return_type)
+            qry = _create_query(user)
             self.context.add_query(qry)
         return return_type
 
@@ -176,12 +196,12 @@ class Web(SecurableObject):
             string parameters, forSharing set to 1 if sharing, and bypass set to 1 to bypass any mobile logic.
         :param bool is_edit_link: If true, the link will allow the logged in user to edit privileges on the item.
         """
-        result = ClientResult(context)
+        return_type = ClientResult(context)
         params = {"url": url, "isEditLink": is_edit_link}
-        qry = ServiceOperationQuery(context.web, "CreateOrganizationSharingLink", None, params, None, result)
+        qry = ServiceOperationQuery(context.web, "CreateOrganizationSharingLink", None, params, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def destroy_organization_sharing_link(context, url, is_edit_link, remove_associated_sharing_link_group):
@@ -265,15 +285,18 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
-    def list_acs_service_principals(self):
+    def get_acs_service_principals(self, app_ids=None):
         """
         List service principals
+        :para, list[str] appIds:
         """
+        payload = {"appIds": app_ids}
         return_type = ClientResult(self.context, ClientValueCollection(SPACSServicePrincipalInfo))
-        qry = ServiceOperationQuery(self, "ListACSServicePrincipals", None, None, None, return_type)
+        qry = ServiceOperationQuery(self, "GetACSServicePrincipals", None, payload, None, return_type)
         self.context.add_query(qry)
         return return_type
 
+
     def sync_flow_instances(self, target_web_url):
         """
         :param str target_web_url:
@@ -295,10 +318,10 @@ class Web(SecurableObject):
         return return_type
 
     def get_all_client_side_components(self):
-        result = ClientResult(self.context)
-        qry = ServiceOperationQuery(self, "GetAllClientSideComponents", None, None, None, result)
+        return_type = ClientResult(self.context, str())
+        qry = ServiceOperationQuery(self, "GetAllClientSideComponents", None, None, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def get_app_bdc_catalog(self):
         """
@@ -312,18 +335,20 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
-    def get_client_side_web_parts(self, project, include_errors=False):
+    def get_client_side_web_parts(self, project=None, include_errors=False):
         """
-        :param str project:
+        It MUST return an array of 3rd party webpart components installed on this site
+
         :param bool include_errors: If true, webparts with errors MUST be included in the results of the request.
            If false, webparts with errors MUST be excluded in the results of the request.
+        :param str project:
         """
         return_type = ClientResult(self.context, ClientValueCollection(SPClientSideComponentQueryResult))
         params = {
             "includeErrors": include_errors,
             "project": project
         }
-        qry = ServiceOperationQuery(self, "getClientSideWebParts", None, params, None, return_type)
+        qry = ServiceOperationQuery(self, "GetClientSideWebParts", None, params, None, return_type)
         self.context.add_query(qry)
         return return_type
 
@@ -337,19 +362,28 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return self
 
+    def get_lists(self):
+        return_type = ListCollection(self.context)
+        payload = {
+            "getListsParams": GetListsParameters()
+        }
+        qry = ServiceOperationQuery(self, "GetLists", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_sub_webs_filtered_for_current_user(self, query):
         """Returns a collection of objects that contain metadata about subsites of the current site (2) in which the
         current user is a member.
 
         :type query: office365.sharepoint.webs.subweb_query.SubwebQuery
         """
-        users = WebInformationCollection(self.context)
+        return_type = WebInformationCollection(self.context)
         qry = ServiceOperationQuery(self, "getSubWebsFilteredForCurrentUser", {
             "nWebTemplateFilter": query.WebTemplateFilter,
             "nConfigurationFilter": query.ConfigurationFilter
-        }, None, None, users)
+        }, None, None, return_type)
         self.context.add_query(qry)
-        return users
+        return return_type
 
     def get_recycle_bin_items(self, paging_info=None, row_limit=100, is_ascending=True, order_by=None, item_state=None):
         """
@@ -361,7 +395,7 @@ class Web(SecurableObject):
         :param int order_by: the column by which to order the Recycle Bin query.
         :param int item_state: Recycle Bin stage of items to return in the query.
         """
-        result = RecycleBinItemCollection(self.context)
+        return_type = RecycleBinItemCollection(self.context)
         payload = {
             "rowLimit": row_limit,
             "isAscending": is_ascending,
@@ -369,9 +403,9 @@ class Web(SecurableObject):
             "orderBy": order_by,
             "itemState": item_state
         }
-        qry = ServiceOperationQuery(self, "GetRecycleBinItems", None, payload, None, result)
+        qry = ServiceOperationQuery(self, "GetRecycleBinItems", None, payload, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def get_all_webs(self):
         """Returns a collection containing a flat list of all Web objects in the Web."""
@@ -442,7 +476,7 @@ class Web(SecurableObject):
 
     def get_regional_datetime_schema(self):
         """Get DateTime Schema based on regional settings"""
-        return_type = ClientResult(self.context)
+        return_type = ClientResult(self.context, str())
         qry = ServiceOperationQuery(self, "GetRegionalDateTimeSchema", None, None, None, return_type)
         self.context.add_query(qry)
         return return_type
@@ -467,7 +501,7 @@ class Web(SecurableObject):
 
         :type context: office365.sharepoint.client_context.ClientContext
         """
-        result = ClientResult(context)
+        result = ClientResult(context, str())
         qry = ServiceOperationQuery(context.web, "GetContextWebThemeData", None, None, None, result)
         qry.static = True
         context.add_query(qry)
@@ -493,15 +527,15 @@ class Web(SecurableObject):
         string parameters
         :param office365.sharepoint.client_context.ClientContext context: client context
         """
-        result = ClientResult(context)
+        return_type = ClientResult(context, str())
         payload = {
             "url": context.create_safe_url(url, False),
             "isEditLink": is_edit_link
         }
-        qry = ServiceOperationQuery(context.web, "CreateAnonymousLink", None, payload, None, result)
+        qry = ServiceOperationQuery(context.web, "CreateAnonymousLink", None, payload, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def create_anonymous_link_with_expiration(context, url, is_edit_link, expiration_string):
@@ -517,16 +551,16 @@ class Web(SecurableObject):
         UTC time. Midnight is represented as 00:00:00.
         :param office365.sharepoint.client_context.ClientContext context: client context
         """
-        result = ClientResult(context)
+        return_type = ClientResult(context, str())
         payload = {
             "url": context.create_safe_url(url, False),
             "isEditLink": is_edit_link,
             "expirationString": expiration_string
         }
-        qry = ServiceOperationQuery(context.web, "CreateAnonymousLinkWithExpiration", None, payload, None, result)
+        qry = ServiceOperationQuery(context.web, "CreateAnonymousLinkWithExpiration", None, payload, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def get_object_sharing_settings(context, object_url, group_id, use_simplified_roles):
@@ -557,26 +591,43 @@ class Web(SecurableObject):
         context.add_query(qry)
         return return_type
 
+    def get_client_side_components_by_id(self, component_ids=None):
+        """
+        Returns the client side components for the requested component identifiers.
+        Client components include data necessary to render Client Side Web Parts and Client Side Applications.
+
+        :param list[str] component_ids: List of requested component identifiers.
+        """
+        return_type = ClientResult(self.context, ClientValueCollection(SPClientSideComponentQueryResult))
+        payload = {
+            "componentIds": StringCollection(component_ids)
+        }
+        qry = ServiceOperationQuery(self, "GetClientSideComponentsById", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_file_by_server_relative_url(self, url):
-        """Returns the file object located at the specified server-relative URL.
-        :type url: str
+        """
+        Returns the file object located at the specified server-relative URL.
+
+        :param str url: Specifies the server-relative URL for the file.
         """
         return File(self.context, ServiceOperationPath("getFileByServerRelativeUrl", [url], self.resource_path))
 
-    def get_file_by_server_relative_path(self, url_or_path):
+    def get_file_by_server_relative_path(self, decoded_url):
         """Returns the file object located at the specified server-relative path.
         Prefer this method over get_folder_by_server_relative_url since it supports % and # symbols in names
 
-        :type url_or_path: str or SPResPath
+        :param str or SPResPath decoded_url: Contains the server-relative path of the file.
         """
-        path = url_or_path if isinstance(url_or_path, SPResPath) else SPResPath(url_or_path)
+        path = decoded_url if isinstance(decoded_url, SPResPath) else SPResPath(decoded_url)
         return File(self.context,
                     ServiceOperationPath("getFileByServerRelativePath", path.to_json(), self.resource_path))
 
     def get_folder_by_server_relative_url(self, url):
         """Returns the folder object located at the specified server-relative URL.
 
-        :type url: str
+        :param str url: Specifies the server-relative URL for the folder.
         """
         return Folder(self.context, ServiceOperationPath("getFolderByServerRelativeUrl", [url], self.resource_path))
 
@@ -584,7 +635,7 @@ class Web(SecurableObject):
         """Returns the folder object located at the specified server-relative URL.
         Prefer this method over get_folder_by_server_relative_url since it supports % and # symbols
 
-        :type decoded_url: str
+        :param str decoded_url: Contains the server-relative URL for the folder.
         """
         path = SPResPath(decoded_url)
         return Folder(self.context,
@@ -633,12 +684,12 @@ class Web(SecurableObject):
     def does_user_have_permissions(self, permission_mask):
         """Returns whether the current user has the given set of permissions.
 
-        :type permission_mask: BasePermissions
+        :param BasePermissions permission_mask: Specifies the set of permissions to verify.
         """
-        result = ClientResult(self.context)
-        qry = ServiceOperationQuery(self, "DoesUserHavePermissions", permission_mask, None, None, result)
+        return_type = ClientResult(self.context, bool())
+        qry = ServiceOperationQuery(self, "DoesUserHavePermissions", permission_mask, None, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def does_push_notification_subscriber_exist(self, device_app_instance_id):
         """
@@ -647,11 +698,11 @@ class Web(SecurableObject):
 
         :param str device_app_instance_id: Device application instance identifier.
         """
-        result = ClientResult(self.context)
+        return_type = ClientResult(self.context, bool())
         params = {"deviceAppInstanceId": device_app_instance_id}
-        qry = ServiceOperationQuery(self, "DoesPushNotificationSubscriberExist", params, None, None, result)
+        qry = ServiceOperationQuery(self, "DoesPushNotificationSubscriberExist", params, None, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def get_folder_by_id(self, unique_id):
         """
@@ -675,7 +726,7 @@ class Web(SecurableObject):
     def get_list(self, path):
         """Get list by path
 
-        :type path: str
+        :param str path: A string that contains the site-relative URL for a list, for example, /Lists/Announcements.
         """
         safe_path = self.context.create_safe_url(path)
         return List(self.context, ServiceOperationPath("getList", [safe_path], self.resource_path))
@@ -686,10 +737,10 @@ class Web(SecurableObject):
 
         :param office365.sharepoint.changes.query.ChangeQuery query: Specifies which changes to return
         """
-        changes = ChangeCollection(self.context)
-        qry = ServiceOperationQuery(self, "getChanges", None, query, "query", changes)
+        return_type = ChangeCollection(self.context)
+        qry = ServiceOperationQuery(self, "getChanges", None, query, "query", return_type)
         self.context.add_query(qry)
-        return changes
+        return return_type
 
     def get_available_web_templates(self, lcid=1033, do_include_cross_language=False):
         """
@@ -697,14 +748,13 @@ class Web(SecurableObject):
 
         :param int lcid: Specifies the LCID of the site templates to be retrieved.
         :param bool do_include_cross_language: Specifies whether to include language-neutral site templates.
-        :return:
         """
         params = {
             "lcid": lcid,
             "doIncludeCrossLanguage": do_include_cross_language
         }
         return_type = WebTemplateCollection(self.context,
-                                            ServiceOperationPath("GetAvailableWebTemplates ", params,
+                                            ServiceOperationPath("GetAvailableWebTemplates", params,
                                                                  self.resource_path))
 
         qry = ServiceOperationQuery(self, "GetAvailableWebTemplates", params, None, None, return_type)
@@ -746,7 +796,6 @@ class Web(SecurableObject):
     def get_custom_list_templates(self):
         """
         Specifies the collection of custom list templates for a given site.
-
         """
         return_type = ListTemplateCollection(self.context)
         qry = ServiceOperationQuery(self, "GetCustomListTemplates", None, None, None, return_type)
@@ -957,14 +1006,14 @@ class Web(SecurableObject):
         :param office365.sharepoint.client_context.ClientContext context: SharePoint context
         :param str web_full_url: The URL of the web.
         """
-        result = ClientResult(context, ClientValueCollection(DocumentLibraryInformation))
+        return_type = ClientResult(context, ClientValueCollection(DocumentLibraryInformation))
         payload = {
             "webFullUrl": web_full_url
         }
-        qry = ServiceOperationQuery(context.web, "GetDocumentLibraries", None, payload, None, result)
+        qry = ServiceOperationQuery(context.web, "GetDocumentLibraries", None, payload, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def default_document_library_url(context, web_url):
@@ -974,14 +1023,13 @@ class Web(SecurableObject):
         :param office365.sharepoint.client_context.ClientContext context: SharePoint context
         :param str web_url:  URL of the web.
         """
-        result = ClientResult(context, DocumentLibraryInformation())
+        return_type = ClientResult(context, DocumentLibraryInformation())
         payload = {
             "webUrl": web_url,
         }
-        qry = ServiceOperationQuery(context.web, "DefaultDocumentLibraryUrl", None, payload, None, result)
-        qry.static = True
+        qry = ServiceOperationQuery(context.web, "DefaultDocumentLibraryUrl", None, payload, None, return_type, True)
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def delete_all_anonymous_links_for_object(context, url):
@@ -1034,15 +1082,15 @@ class Web(SecurableObject):
         :param str web_full_url:  URL of the web.
         :param bool include_page_libraries: Indicates whether to include page libraries. A value of "true" means yes.
         """
-        result = ClientResult(context, ClientValueCollection(DocumentLibraryInformation))
+        return_type = ClientResult(context, ClientValueCollection(DocumentLibraryInformation))
         payload = {
             "webFullUrl": web_full_url,
             "includePageLibraries": include_page_libraries
         }
-        qry = ServiceOperationQuery(context.web, "GetDocumentAndMediaLibraries", None, payload, None, result)
+        qry = ServiceOperationQuery(context.web, "GetDocumentAndMediaLibraries", None, payload, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def get_sharing_link_kind(context, file_url, return_type=None):
@@ -1075,17 +1123,17 @@ class Web(SecurableObject):
         :param str email_subject: The email subject.
         :param str email_body: The email subject.
         """
-        result = SharingResult(context)
+        return_type = SharingResult(context)
         payload = {
             "url": url,
             "peoplePickerInput": people_picker_input,
             "emailSubject": email_subject,
             "emailBody": email_body,
         }
-        qry = ServiceOperationQuery(context.web, "ForwardObjectLink", None, payload, None, result)
+        qry = ServiceOperationQuery(context.web, "ForwardObjectLink", None, payload, None, return_type)
         qry.static = True
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def share_object(context, url, people_picker_input,
@@ -1279,6 +1327,21 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return self
 
+    def assign_document_id(self, site_prefix, enabled=True):
+        """
+        Assign Document IDs
+
+        :param str site_prefix: Specify whether IDs will be automatically assigned to all documents in the
+            Site Collection. Additionally, you can specify a set of 4-12 characters that will be used at the beginning
+            of all IDs assigned for documents in this Site Collection, to help ensure that items in different
+            Site Collections will never get the same ID. Note: A timer job will be scheduled to assign IDs to
+            documents already in the Site Collection.
+        :param bool enabled:
+        """
+
+        props = {'docid_x005f_msft_x005f_hier_x005f_siteprefix': site_prefix, 'docid_x005f_enabled': "1"}
+        return self.set_property("AllProperties", props).update()
+
     @property
     def activities(self):
         return self.properties.get("Activities",
@@ -1306,6 +1369,14 @@ class Web(SecurableObject):
         """
         return self.properties.get("AlternateCssUrl", None)
 
+    @property
+    def app_instance_id(self):
+        """
+        Specifies the identifier of the app instance that this site (2) represents. If this site (2) does not
+        represent an app instance, then this MUST specify an empty GUID.
+        """
+        return self.properties.get("AppInstanceId", None)
+
     @property
     def author(self):
         """
@@ -1363,6 +1434,18 @@ class Web(SecurableObject):
         from office365.sharepoint.permissions.base_permissions import BasePermissions
         return self.properties.get("EffectiveBasePermissions", BasePermissions())
 
+    @property
+    def enable_minimal_download(self):
+        """
+        Specifies whether the site will use the minimal download strategy by default.
+
+        The minimal download strategy will use a single .aspx file (start.aspx) for your pages, with the actual URL
+        encoded in the text following the hash mark ('#'). When navigating from page to page, only the changes
+        between two compatible pages will be downloaded. Fewer bytes will be downloaded and the page will appear
+        more quickly.
+        """
+        return self.properties.get("EnableMinimalDownload", None)
+
     @property
     def webs(self):
         """Specifies the collection of all child sites for the site"""
@@ -1445,6 +1528,15 @@ class Web(SecurableObject):
                                    ContentTypeCollection(self.context,
                                                          ResourcePath("ContentTypes", self.resource_path), self))
 
+    @property
+    def configuration(self):
+        """
+        Specifies the identifier (ID) of the site definition that was used to create the site (2). If the site (2)
+        was created with a custom site template this specifies the identifier (ID) of the site definition from which
+        the custom site template is derived.
+        """
+        return self.properties.get("Configuration", None)
+
     @property
     def description_resource(self):
         """A UserResource object that represents the description of this web."""
@@ -1463,7 +1555,7 @@ class Web(SecurableObject):
         """Specifies the collection of event receiver definitions that are currently available on the Web site"""
         return self.properties.get('EventReceivers',
                                    EventReceiverDefinitionCollection(self.context,
-                                                                     ResourcePath("eventReceivers", self.resource_path),
+                                                                     ResourcePath("EventReceivers", self.resource_path),
                                                                      self))
 
     @property
@@ -1589,6 +1681,11 @@ class Web(SecurableObject):
                                    RecycleBinItemCollection(self.context,
                                                             ResourcePath("RecycleBin", self.resource_path)))
 
+    @property
+    def recycle_bin_enabled(self):
+        """Specifies whether the Recycle Bin is enabled."""
+        return self.properties.get("RecycleBinEnabled", None)
+
     @property
     def navigation(self):
         """Specifies the navigation structure on the site (2), including the Quick Launch area and the link bar."""
@@ -1600,9 +1697,9 @@ class Web(SecurableObject):
     def push_notification_subscribers(self):
         """Specifies the collection of push notification subscribers for the site"""
         return self.properties.get('PushNotificationSubscribers',
-                                   BaseEntityCollection(self.context, PushNotificationSubscriber,
-                                                        ResourcePath("PushNotificationSubscribers",
-                                                                     self.resource_path)))
+                                   PushNotificationSubscriberCollection(self.context,
+                                                                        ResourcePath("PushNotificationSubscribers",
+                                                                                     self.resource_path)))
 
     @property
     def root_folder(self):
@@ -1688,12 +1785,22 @@ class Web(SecurableObject):
         """
         return self.properties.get("ServerRelativePath", SPResPath())
 
+    @property
+    def syndication_enabled(self):
+        """Specifies whether the [RSS2.0] feeds are enabled on the site"""
+        return self.properties.get("SyndicationEnabled", None)
+
     @property
     def title_resource(self):
         """A UserResource object that represents the title of this web."""
         return self.properties.get('TitleResource',
                                    UserResource(self.context, ResourcePath("TitleResource", self.resource_path)))
 
+    @property
+    def treeview_enabled(self):
+        """Specifies whether the tree view is enabled on the site """
+        return self.properties.get("TreeViewEnabled", None)
+
     def get_property(self, name, default_value=None):
         if default_value is None:
             property_mapping = {
